"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.start = void 0;
const debug_1 = __importDefault(require("debug"));
const vite_1 = require("vite");
const path_1 = require("path");
const get_port_1 = __importDefault(require("get-port"));
const makeCypressPlugin_1 = require("./makeCypressPlugin");
const debug = debug_1.default('cypress:vite-dev-server:start');
const resolveServerConfig = async ({ viteConfig, options }) => {
    const { projectRoot, supportFile } = options.config;
    const requiredOptions = {
        base: '/__cypress/src/',
        root: projectRoot,
    };
    const finalConfig = { ...viteConfig, ...requiredOptions };
    finalConfig.plugins = [...(viteConfig.plugins || []), makeCypressPlugin_1.makeCypressPlugin(projectRoot, supportFile, options.devServerEvents)];
    // This alias is necessary to avoid a "prefixIdentifiers" issue from slots mounting
    // only cjs compiler-core accepts using prefixIdentifiers in slots which vue test utils use.
    // Could we resolve this usage in test-utils?
    finalConfig.resolve = finalConfig.resolve || {};
    try {
        finalConfig.resolve.alias = {
            ...finalConfig.resolve.alias,
            '@vue/compiler-core': path_1.resolve(path_1.dirname(require.resolve('@vue/compiler-core')), 'dist', 'compiler-core.cjs.js'),
        };
    }
    catch (e) {
        // Vue 3 is not installed
    }
    finalConfig.server = finalConfig.server || {};
    finalConfig.server.port = await get_port_1.default({ port: finalConfig.server.port || 3000, host: 'localhost' }),
        debug(`the resolved server config is ${JSON.stringify(finalConfig, null, 2)}`);
    return finalConfig;
};
async function start(devServerOptions) {
    if (!devServerOptions.viteConfig) {
        debug('User did not pass in any Vite dev server configuration');
        devServerOptions.viteConfig = {};
    }
    debug('starting vite dev server');
    const resolvedConfig = await resolveServerConfig(devServerOptions);
    return vite_1.createServer(resolvedConfig);
}
exports.start = start;
